<div class="fancy header" dir="ltr">

    <div dir="ltr"> {{ header.subject|safe }}
    </div>
<table class="outer">
    <tbody>
    <tr>
    <td width="100%">

    <table>

    <tr>
    <th align="left" style="font-size: 10px;">{{ header.fromi18n }}</th>
    <td style="font-size: 10px;">{{ header.from.str}}

    {% if header.resentFrom %}
      &nbsp; {{ header.resentFromi18n }} {{ header.resentFrom }}
    {% endif %}

    {% if vCardName %}
      &nbsp;&nbsp;<a href="{{ header.vcardname|safe }}">{{ header.vcardi18n }}</a>
    {% endif %}

    {% if header.organization %}
      &nbsp;&nbsp;("{{ header.organization}}")
    {% endif %}

    </td>
    </tr>

    <tr>
    <th align="left" style="font-size: 10px;">{{ header.toi18n }}</th>
    <td style="font-size: 10px;">{{ header.to.expandableTo|safe }}</td>
    </tr>

{% if header.cc.isSet %}
    <tr>
    <th align="left" style="font-size: 10px;"> {{ header.cci18n }} </th>
    <td style="font-size: 10px;">{{ header.cc.expandableCc|safe }}</td>
    </tr>
{% endif %}

{% if header.bcc.isSet %}
    <tr>
    <th align="left" style="font-size: 10px;"> {{ header.bcci18n }} </th>
    <td style="font-size: 10px;">{{ header.bcc.expandableBCC|safe }}</td>
    </tr>
{% endif %}

{% if header.sender.isSet %}
    <tr>
    <th align="left" style="font-size: 10px;"> {{ header.senderi18n }} </th>
    <td style="font-size: 10px;">{{ header.sender.str }}</td>
    </tr>
{% endif %}

{% if header.ListId %}
    <tr>
    <th align="left" style="font-size: 10px;"> List-Id: </th>
    <td style="font-size: 10px;">{{ header.ListId }}</td>
    </tr>
{% endif %}

    <tr>
    <th align="left" style="font-size: 10px;">{{ header.datei18n }} </th>
    <td dir="{{ dateDir }}" style="font-size: 10px;">{{ header.date.short }}</td>
    </tr>

    <tr>
    <td colspan="2"><div id="attachmentInjectionPoint"></div></td>
    </tr>

    </table>
    </td>

{% if header.photourl %}
    <td align="center">
    <div style="font-size:0.8em ! important;border:1px solid black ! important;background-color:#3384b3 ! important;">
      <img src="{{ header.photourl }}" width="{{ header.photowidth }}" height="{{ header.photoheight }}" />
    </div>
    </td>
{% endif %}

    </tr>

{% if header.spamHTML %}
  <table >
  <tbody>
  <tr>
    <td>
      <div class="spamheader" >
      <span><b>{{ header.spamstatusi18n }}</b></span>&nbsp;
      <span>{{ header.spamHTML|safe }}</span>
      </div>
    </td>
  </tr>
  </tbody>
  </table>
{% endif %}
</tbody>
</table>

</div>
