/*
   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "selectmaildialogtest.h"

#include <QTest>
QTEST_MAIN(SelectMailDialogTest)

SelectMailDialogTest::SelectMailDialogTest(QObject *parent)
    : QObject(parent)
{
}
