/*
   SPDX-FileCopyrightText: 2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

namespace AkonadiDatabaseToolsUtils
{
enum AkonadiDatabaseTool {
    Unknown = 0,
    Vacuum = 1,
    Fsck = 2,
};
}
