/*
   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "adblockmanagertest.h"

AdblockManagerTest::AdblockManagerTest(QObject *parent)
    : QObject(parent)
{
}

AdblockManagerTest::~AdblockManagerTest()
{
}

QTEST_MAIN(AdblockManagerTest)
