/*
   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "checkgravatarplugintest.h"

CheckGravatarPluginTest::CheckGravatarPluginTest(QObject *parent)
    : QObject(parent)
{
}

QTEST_MAIN(CheckGravatarPluginTest)
