/*
   SPDX-FileCopyrightText: 2018-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "markdownconfiguredialogtest.h"
#include "markdownconfiguredialog.h"
#include <QTest>
QTEST_MAIN(MarkdownConfigureDialogTest)

MarkdownConfigureDialogTest::MarkdownConfigureDialogTest(QObject *parent)
    : QObject(parent)
{
}
