/*
  SPDX-FileCopyrightText: 2021-2022 Laurent Montel <montel@kde.org>

  SPDX-License-Identifier: GPL-2.0-only
*/

#include "mailmergepreviewwidget.h"

MailMergePreviewWidget::MailMergePreviewWidget(QWidget *parent)
    : QWidget(parent)
{
}

MailMergePreviewWidget::~MailMergePreviewWidget() = default;
