/*
   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "gearyaddressbook.h"

GearyAddressBook::GearyAddressBook(const QString &filename)
{
}

GearyAddressBook::~GearyAddressBook() = default;

void GearyAddressBook::importAddressBook()
{
}
