/*
   SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "languagetoollistoflanguagesparsertest.h"
#include <QTest>
QTEST_GUILESS_MAIN(LanguageToolListOfLanguagesParserTest)

LanguageToolListOfLanguagesParserTest::LanguageToolListOfLanguagesParserTest(QObject *parent)
    : QObject(parent)
{
}
